from .individu import DataIndividu
from .kesehatan import DataKesehatan
from .pekerjaan import DataPekerjaan
from .penghasilan import Penghasilan, DataPenghasilan
from .wilayah import DataWilayah

from .tambah import tambah_individu

__all__ = [
    "DataIndividu",
    "DataKesehatan",
    "DataPekerjaan",
    "DataPenghasilan",
    "DataWilayah",
    "Penghasilan",
    "tambah_individu",
]
